.icon[data-v-4323f8ce]{font-size:1rem;margin-right:.5rem}.menu hr[data-v-4323f8ce]{margin-top:.5rem;margin-bottom:.5rem}.menu .container-xxl[data-v-4323f8ce]{background-color:var(--secondary-background-color);border-radius:.5rem}.menu-title[data-v-4323f8ce]{margin-left:.75rem;margin-right:.75rem}.menu-title .icon[data-v-4323f8ce],.menu-title[data-v-4323f8ce]{font-size:1.5rem}.menu-title .icon[data-v-4323f8ce]{margin-right:.75rem}.menu-title[data-v-4323f8ce],.menu .nav-item[data-v-4323f8ce],.menu .nav-link[data-v-4323f8ce],hr[data-v-4323f8ce]{color:var(--text-color)}.nav-link.active[data-v-4323f8ce]{color:#fff}.nav-link[data-v-4323f8ce]:hover{background-color:var(--hover-color)}.nav-link-hover[data-v-4323f8ce]:hover{background-color:inherit}.menu .nav-link[data-v-4323f8ce]{margin-top:.25rem;margin-bottom:.25rem;padding-top:.5rem;padding-bottom:.5rem}.menu .nav-link-horizontal[data-v-4323f8ce]{padding-top:.25rem;padding-bottom:.25rem}.p-h[data-v-4323f8ce]{padding:.5rem .75rem}.container .flex-column[data-v-4323f8ce]{padding-top:.25rem}.menu .nav-item .nav-link.active[data-v-4323f8ce]{background-color:var(--primary-color)}.nav-link.active+.icon[data-v-4323f8ce],.nav-link.active[data-v-4323f8ce]{font-weight:900}.vr[data-v-4323f8ce]{width:1px;height:80%}.err__msg[data-v-bef81972],.err__title[data-v-bef81972]{margin:0}body{margin:0}#app{font-family:Avenir,Helvetica,Arial,sans-serif;-webkit-font-smoothing:antialiased;-moz-osx-font-smoothing:grayscale;color:#2c3e50}